@@ -131,10 +131,11 @@ sub _loadCredentials($s) {
     $l->info("Loading credentials from file '$c'");
     my @rows = File::Slurp::read_file( $c => { binmode => ':encoding(UTF-8)' } );
     $c = $rows[0];
+    chomp $c;
   }
 
   unless ($c =~ /^(.+):(.+)$/) {
-    Pootle::Exception::Credentials->throw(error => "_loadCredentials():> Given credentials ".($file ? "from file '$file' " : "")."are malformed. Credentials must look like username:password");
+    Pootle::Exception::Credentials->throw(error => "_loadCredentials():> Given credentials ".($file ? "from file '$file' " : "")."are malformed. Credentials must look like username:password, or point to a file.");
   }
   return $c;
 }
